PlayerCustomizer class abstract

Implementers

Constructors

PlayerCustomizer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
row1col1 → Widget?
no setter
row1col2 → Widget?
no setter
row1Exists → bool
no setter
row2col1 → Widget?
no setter
row2col2 → Widget?
no setter
row2col3 → Widget?
no setter
row2col4 → Widget?
no setter
row2Exists → bool
no setter
row3col1 → Widget?
no setter
row3col2 → Widget?
no setter
row3col3 → Widget?
no setter
row3col4 → Widget?
no setter
row3Exists → bool
no setter
row4col1 → Widget?
no setter
row4col2 → Widget?
no setter
row4Exists → bool
no setter
row5col1 → Widget?
no setter
row5col2 → Widget?
no setter
row5col3 → Widget?
no setter
row5col4 → Widget?
no setter
row5Exists → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited