AudioTrack class

Constructors

AudioTrack(Object id, {required String title, required String artist, required Duration duration, String? networkUrl, String? filePath})

Properties

albumCover ↔ Uint8List?
getter/setter pair
artist → String
final
duration → Duration
final
filePath ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → Object
final
networkUrl ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited